#!/bin/bash

set -euo pipefail

base="$( cd "$(dirname "${BASH_SOURCE[0]}")" && pwd )"

# Allow this script to be run only by ubuntu-it
if [[ "$(whoami)" != "ubuntu-it-web" ]]; then
    echo "Error: this script must be executed by the ubuntu-it-web user"
    exit 1
fi

run_script() (
    if [[ ! -x "${script}" ]]; then
        # suppress message if not running in a terminal
        if [[ -t 1 ]]; then
            echo "$(basename "$script"): not executable, skipping"
        fi
        return
    fi
    # Create a temporary build directory
    build_dir="$(mktemp -d deploy-XXXXXXXXX -p /tmp)"
    trap 'rm -rf "$build_dir"' EXIT

    # Switch to the temporary build directory
    cd "${build_dir}"
    export HOME="${build_dir}"
    TMPDIR="$HOME"
    output="$(mktemp -p "${TMPDIR:-/tmp}" deploy_output.XXXXXXXX)"

    # Execute the deploy script
    # Capture the output and print it only if the script fails
    "$script" > "$output" 2>&1 || ret=$?
    if [[ "${ret-0}" -ne 0 ]]; then
        echo "Deploy script $(basename "${script}") failed!"
        echo "Return code: $ret"
        echo "Script output"
        echo "============="
        cat "${output}"
        echo
    fi

    # Restore the old home
    cd "${base}"
    export HOME="${base}"
)


if [ $# -ne 0 ]; then
    for i in "$@"; do
        script="$base/scripts/$i"
        run_script "$script"
    done
else
    # Try to deploy all the websites
    for script in "${base}/scripts/"*; do
        run_script "$script"
    done
fi
