#!/bin/bash


# Clone a bazaar repository in /srv/{name}/repo
#
# $ bzr_clone_repo www.ubuntu-it.org lp:ubuntu-it-www
bzr_clone_repo() {
    name="$1"
    url="$2"

    dest="${DIR_BASE}/${name}/repo"

    if [[ ! -d "${dest}" ]]; then
        bzr branch "${url}" "${dest}" -q
    else
        (cd "${dest}" && bzr pull -q)
    fi
}


# Check if a new deploy for the service is needed
#
# $ bzr_needs_update www.ubuntu-it.org
bzr_needs_update() {
    name="$1"

    repo="${DIR_BASE}/${name}/repo"
    current="${DIR_BASE}/${name}/current/.revision"

    if [[ ! -f "${current}" ]]; then
        return 0
    fi

    latest="$(cd "${repo}" && bzr revno)"

    if [[ "$(cat "${current}")" != "${latest}" ]]; then
        return 0
    else
        return 1
    fi
}


# Save the revision for this service in the provided build
#
# $ bzr_save_revision www.ubuntu-it.org /srv/www.ubuntu-it.org/builds/XXXXXX
bzr_save_revision() {
    name="$1"
    build="$2"

    repo="${DIR_BASE}/${name}/repo"
    dest="${build}/.revision"

    (cd "${repo}" && bzr revno) > "${dest}"
}
