#!/bin/bash


# Clone a git repository in /srv/{name}/repo
#
# $ git_clone_repo static.ubuntu-it.org git@code.ubuntu-it.org:ubuntu-it-web/static
git_clone_repo() {
    name="$1"
    url="$2"

    dest="${DIR_BASE}/${name}/repo"

    if [[ ! -d "${dest}" ]]; then
        git clone "${url}" "${dest}" -q
    else
        (cd "${dest}" && git pull -q)
    fi

    echo "${dest}"
}


# Check if a new deploy for the service is needed
#
# $ git_needs_update www.ubuntu-it.org
git_needs_update() {
    name="$1"

    repo="${DIR_BASE}/${name}/repo"
    current="${DIR_BASE}/${name}/current/.commit"

    if [[ ! -f "${current}" ]]; then
        return 0
    fi

    latest="$(cd "${repo}" && git rev-parse master)"

    if [[ "$(cat "${current}")" != "${latest}" ]]; then
        return 0
    else
        return 1
    fi
}


# Save the revision for this service in the provided build
#
# $ git_save_revision www.ubuntu-it.org /srv/www.ubuntu-it.org/builds/XXXXXX
git_save_revision() {
    name="$1"
    build="$2"

    repo="${DIR_BASE}/${name}/repo"
    dest="${build}/.commit"

    (cd "${repo}" && git rev-parse master) > "${dest}"
}
